Software Heritage - Object storage replayer
===========================================

Simple command line tool to replicate content objects from a source object
storage to a destination one by listening the ``content`` topic of a
``swh.journal`` kafka stream.
